@@ -69,6 +69,7 @@ pub enum SyntaxError {
         c: char,
     },
     InvalidStrEscape,
+    InvalidUnicodeCodePoint,
     InvalidUnicodeEscape,
     InvalidCodePoint,
     ExpectedHexChars {
@@ -266,6 +267,7 @@ impl SyntaxError {
             SyntaxError::IdentAfterNum => "Identifier cannot follow number".into(),
             SyntaxError::UnexpectedChar { c } => format!("Unexpected character {:?}", c).into(),
             SyntaxError::InvalidStrEscape => "Invalid string escape".into(),
+            SyntaxError::InvalidUnicodeCodePoint => "Undefined Unicode code-point".into(),
             SyntaxError::InvalidUnicodeEscape => "Invalid unicode escape".into(),
             SyntaxError::InvalidCodePoint => "Invalid unicode code point".into(),
             SyntaxError::ExpectedHexChars { count } => {
