@@ -154,6 +154,7 @@ impl<I: Input> Tokens for Lexer<'_, I> {
 impl<'a, I: Input> Iterator for Lexer<'a, I> {
     type Item = TokenAndSpan;
     fn next(&mut self) -> Option<Self::Item> {
+        let was_first = self.state.is_first;
         let mut start = self.cur_pos();
 
         let res = (|| -> Result<Option<_>, _> {
@@ -176,8 +177,6 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
                 Some(c) => c,
                 // End of input.
                 None => {
-                    // Treat last comments as trailing.
-
                     if self
                         .leading_comments_buffer
                         .as_ref()
@@ -193,7 +192,15 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
                             .unwrap()
                             .drain(..)
                         {
-                            self.comments.as_mut().unwrap().add_trailing(last, c);
+                            let comments = self.comments.as_mut().unwrap();
+
+                            // if the file had no tokens, then treat any comments in the leading
+                            // comments buffer as leading. Otherwise treat them as trailing.
+                            if was_first {
+                                comments.add_leading(last, c);
+                            } else {
+                                comments.add_trailing(last, c);
+                            }
                         }
                     }
 
@@ -209,16 +216,6 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
 
             self.state.start = start;
 
-            if self.syntax.typescript() && self.ctx.in_type {
-                if c == '<' {
-                    self.input.bump();
-                    return Ok(Some(tok!('<')));
-                } else if c == '>' {
-                    self.input.bump();
-                    return Ok(Some(tok!('>')));
-                }
-            }
-
             if self.syntax.jsx() && !self.ctx.in_property_name && !self.ctx.in_type {
                 //jsx
                 if self.state.context.current() == Some(TokenContext::JSXExpr) {
@@ -257,10 +254,20 @@ impl<'a, I: Input> Iterator for Lexer<'a, I> {
                 start: start_pos_of_tpl,
             }) = self.state.context.current()
             {
-                self.read_tmpl_token(start_pos_of_tpl).map(Some)
-            } else {
-                self.read_token()
+                return self.read_tmpl_token(start_pos_of_tpl).map(Some);
             }
+
+            if self.syntax.typescript() && self.ctx.in_type {
+                if c == '<' {
+                    self.input.bump();
+                    return Ok(Some(tok!('<')));
+                } else if c == '>' {
+                    self.input.bump();
+                    return Ok(Some(tok!('>')));
+                }
+            }
+
+            self.read_token()
         })();
 
         let token = match res.map_err(Token::Error).map_err(Some) {
